/*
 *  linux/drivers/video/vgacon.c -- Low level VGA based console driver
 *
 *	Created 28 Sep 1997 by Geert Uytterhoeven
 *
 *	Rewritten by Martin Mares <mj@ucw.cz>, July 1998
 *
 *  This file is based on the old console.c, vga.c and vesa_blank.c drivers.
 *
 *	Copyright (C) 1991, 1992  Linus Torvalds
 *			    1995  Jay Estabrook
 *
 *	User definable mapping table and font loading by Eugene G. Crosser,
 *	<crosser@pccross.msk.su>
 *
 *	Improved loadable font/UTF-8 support by H. Peter Anvin
 *	Feb-Sep 1995 <peter.anvin@linux.org>
 *
 *	Colour palette handling, by Simon Tatham
 *	17-Jun-95 <sgt20@cam.ac.uk>
 *
 *	if 512 char mode is already enabled don't re-enable it,
 *	because it causes screen to flicker, by Mitja Horvat
 *	5-May-96 <mitja.horvat@guest.arnes.si>
 *
 *	Use 2 outw instead of 4 outb_p to reduce erroneous text
 *	flashing on RHS of screen during heavy console scrolling .
 *	Oct 1996, Paul Gortmaker.
 *
 *
 *  This file is subject to the terms and conditions of the GNU General Public
 *  License.  See the file COPYING in the main directory of this archive for
 *  more details.
 */

/* sorry, but we put our vga registers at vga_base + 0x00800000
 */
#include <linux/pci.h>
volatile unsigned char* vga_regs_base;

#undef outw
#undef outb_p
#undef inb_p
#define outw(d,p)   *(volatile unsigned short*)(vga_regs_base+p)=d
#define outb_p(d,p) *(volatile unsigned char*) (vga_regs_base+p)=d
#define inb_p(p)    *(volatile unsigned char*) (vga_regs_base+p)


static volatile char* vga_regs;

static void w_seq(int reg, int data) {
 	vga_regs[0x3c4] = reg;
 	vga_regs[0x3c5] = data;
}

static void w_crt(int reg, int data) {
 	vga_regs[0x3d4] = reg;
 	vga_regs[0x3d5] = data;
}
static void w_grf(int reg, int data) {
 	vga_regs[0x3ce] = reg;
 	vga_regs[0x3cf] = data;
}
static void w_atr(int reg, int data) {
 	volatile char a;
 	a = vga_regs[0x3da];
 	vga_regs[0x3c0] = reg;
 	a = vga_regs[0x3c1];
 	vga_regs[0x3c0] = data;
}

static void delay(volatile int i) { while (i--); }

extern unsigned char chars8x16[256][16];

/* The NetWinder may not have set up the vga properly,
 so this code is bios-equivalent.

 Note that this routine is called at "setup" time, which
 is really early in the boot process. At this early stage,
 you cannot even call pci_* services, because the pci bus
 has not been scanned yet.

 The "init" calls come later, after pci has been set up.
 But we need the screen to accept printk message, so
 most of the work is done here.

 This routine probes for the pci address and returns
 it to the caller.
 
 Return 0 if the board cannot be found.
 */
static int setup_igs(unsigned long* pVgaBase,
                     volatile unsigned char** pVgaRegs) {

    volatile unsigned char* p;
    volatile unsigned long* pConfig;
    volatile unsigned char* vbase;
    char a;
    int i;
    int j;

    /* scan the PCI bus */
    for (i=0; i<16; i++) {
        unsigned int vendor_device;
        pConfig = (unsigned long*)(PCI_CONFIG_BASE | 0x00C00000 | (i<<11));
        vendor_device = pConfig[0];
        if (vendor_device == (PCI_VENDOR_ID_INTERG | (0x2000 << 16)))
            break;
    }
    if (i==16) return 0;

    /* configure the chip for our expected state */
    pConfig[4] = CYBER2000_MEM_BASE;
    *(char*) (pConfig+1) = 3; /* enable memory access */

    /* fetch the bus address from the PCI config */
    vbase  = bus_to_virt(pConfig[4]);
    *pVgaBase = (unsigned long) vbase;
    vga_regs = *pVgaRegs  = vbase + 0x00800000;

    // wake up the device
    vga_regs[0x46e8] = 0x18;
    vga_regs[0x102] = 1;
    vga_regs[0x46e8] = 8;

delay(1);
    vga_regs[0x3c2] = 3;		// use B0/B1 clock
    w_crt(0x11, 0x0c);	// unlock CR0-7
    w_atr(0x11,0);

delay(3);
    // set the horizontal and vert totals
    w_seq(0,1);
    w_seq(0,0x3);
    w_seq(1,0x0);	// NOTE!!! asking for 9 bit dot clock hangs the memory
    w_seq(2,0xf);
    w_seq(3,0);
    w_seq(4,2);

delay(3);
    a = vga_regs[0x3cc];
    vga_regs[0x3c2] = 0x67;

    w_crt(0,0x5f);
    w_crt(1,0x4f);
    w_crt(2,0x50);
    w_crt(3,0x82);  // enable read of cr10/11
    w_crt(4,0x55);
    w_crt(5,0x81);
    w_crt(6,0xbf);
    w_crt(7,0x1f);
    w_crt(8,0x0);
    w_crt(9,0x4f);
    w_crt(0xA,0xd);	// cursor enabled
    w_crt(0xB,0x0e);
    w_crt(0xC,0x0);
    w_crt(0xD,0x0);
    w_crt(0xE,0x0);
    w_crt(0xF,0x0);
    w_crt(0x10,0x9c);
    w_crt(0x11,0x0e);
    w_crt(0x12,0x8f);
    w_crt(0x13,0x28);
    w_crt(0x14,0x1f);
    w_crt(0x15,0x96);
    w_crt(0x16,0xb9);
    w_crt(0x17,0xa3);
    w_crt(0x18,0xff);

    w_atr(0,0);
    w_atr(1,1);
    w_atr(2,2);
    w_atr(3,3);
    w_atr(4,4);
    w_atr(5,5);
    w_atr(6,6);
    w_atr(7,7);
    w_atr(8,0x8);
    w_atr(9,0x9);
    w_atr(10,0xa);
    w_atr(11,0xb);
    w_atr(12,0xc);
    w_atr(13,0xd);
    w_atr(14,0xe);
    w_atr(15,0xf);
    w_atr(0x10,0xc);
    w_atr(0x11,0);
    w_atr(0x12,0xF);
    w_atr(0x13,8);
    w_atr(0x14,0);

    w_grf(0,0);
    w_grf(1,0);
    w_grf(2,0);
    w_grf(3,0);
    w_grf(4,0);
    w_grf(5,0x10);
    w_grf(6,0x2);
    w_grf(7,0x0);
    w_grf(8,0xFF);

delay(3);
    // init the palette
    vga_regs[0x3c8] = 0;
    for (i=0; i<255; i++) {
            // assert the R, G and B
            vga_regs[0x3c9] = 64*i+3*i+(i>>1);
            vga_regs[0x3c9] = 75*i+i;
            vga_regs[0x3c9] = 86*i+2*i+(i>>2);
            delay(25);
    }
    vga_regs[0x3c0] = 0x20;
    vga_regs[0x3c6] = 0xFF;
    // and put the palette in low-brightness mode
    // patb 15/10/98
    vga_regs[0x3ce] = 0x56;
    i = vga_regs[0x3cf];
    vga_regs[0x3cf] = i | 4; // unlock 3c6
    vga_regs[0x3c6] = 0x04; // low brightness, palette enabled
    vga_regs[0x3cf] = i;    // lock it up again

delay(3);

    // IGS specific extensions
    w_grf(0x10,0x10);	// ext start addr
    w_grf(0x11,0x0);	// ext crt vert overfl
    w_grf(0x12,0x0);	// ext crt irq
    w_grf(0x13,0x0);	// ext crt test
    w_grf(0x14,0x51);	// ext num of fetch
    w_grf(0x15,0x0);
    w_grf(0x30,0x1);	// ext bus control: 2MB linear ram
    w_grf(0x31,0x0);	// ext seg write pointer
    w_grf(0x32,0x0);
    w_grf(0x33,0x1);	// ext biu misc control; enable linear ram

    w_grf(0x50,0x0);	// sprite params
    w_grf(0x51,0x0);
    w_grf(0x52,0x0);
    w_grf(0x53,0x0);
    w_grf(0x54,0x0);
    w_grf(0x55,0x0);
    w_grf(0x56,0x0);	
    w_grf(0x57,0x0);	// ext attrib: standard mode
    w_grf(0x58,0x0);	// overscans
    w_grf(0x59,0x0);
    w_grf(0x5a,0x0);
//// 	w_grf(0x70,0xb);	// ext mem: multiple cas, 7 mclk
//// 	w_grf(0x71,0x10);	//63);	// ext mem: serial access, 2MB x 16
//// 	w_grf(0x72,0x05);	//2);	// ext mem: 32 bit bus, 4M
//	w_grf(0x73,0x30);	
//	w_grf(0x74,0x1b);	// ext mem: fifo depth
//	w_grf(0x75,0x1e);
    w_grf(0x76,0x0);
    w_grf(0x77,0x0);	// for low res mode! NOTE: the bios may have set this to non-zero
    w_grf(0x7a,0xc8);
    w_grf(0x90,0);		// ext graphics: no bypass gc; NOTE: the bios may have set this to non-zero
    w_grf(0xBF,0);		// ext graphics: point to real b0..b3 regs (wms)
    w_grf(0xb0,0xd2);	// pixel clock
    w_grf(0xb1,0xce);
// 	w_grf(0xb2,0xdb);
// 	w_grf(0xb3,0x54);
    w_grf(0xb9,0x80);	// latch the freqs into the chip
    w_grf(0xb9,0);

    /* linux expect clear ram */
    memzero((unsigned char*)vbase,1024*1024);

    // load font
    w_seq(0, 1);
    w_seq(2, 4);           /* Enable plane 2 */
    w_seq(4, 6);		// go to linear mode
    w_seq(0, 3);
    w_grf(4, 2);
    w_grf(5, 0);
    w_grf(6, 0);
    p = vbase;
    for (j=0; j<256; j++) {
        for (i=0; i<16; i++) {
            *p++ = chars8x16[j][i];
        }
        p+=16;	// only first 32 bytes used
    }
    
    w_seq(0, 1);
    w_seq(2, 3);	// turn on planes 0 & 1
    w_seq(4, 3);
    w_seq(0, 3);
    w_grf(4, 0);
    w_grf(5, 0x10);
    w_grf(6, 2);

    // lock it up
    w_crt(0x11, 0x8e);

#if 0
    // quick test
    for (i=0; i<40; i++) {
        vbase[2*i] = " NetWinder ROX!"[i];
        vbase[2*i+1] = 7;
    }

    delay(100000000);

    p = vbase;
    while (p < vbase+25*80*2)
    {
            *(unsigned int*)p = 0x07200720;	//white spaces on black back
            p += 4;
            delay(100000);
    }
    *(unsigned int*)vbase = 0x07410742;
    delay(100000000);
#endif
    return 1;
}


unsigned char chars8x16[256][16] = {
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 0 */
{0x00,0x00,0x7E,0x81,0xA5,0x81,0x81,0xBD,
0x99,0x81,0x81,0x7E,0x00,0x00,0x00,0x00}, /* 1 */
{0x00,0x00,0x7E,0xFF,0xDB,0xFF,0xFF,0xC3,
0xE7,0xFF,0xFF,0x7E,0x00,0x00,0x00,0x00}, /* 2 */
{0x00,0x00,0x00,0x00,0x6C,0xFE,0xFE,0xFE,
0xFE,0x7C,0x38,0x10,0x00,0x00,0x00,0x00}, /* 3 */
{0x00,0x00,0x00,0x00,0x10,0x38,0x7C,0xFE,
0x7C,0x38,0x10,0x00,0x00,0x00,0x00,0x00}, /* 4 */
{0x00,0x00,0x00,0x18,0x3C,0x3C,0xE7,0xE7,
0xE7,0x99,0x18,0x3C,0x00,0x00,0x00,0x00}, /* 5 */
{0x00,0x00,0x00,0x18,0x3C,0x7E,0xFF,0xFF,
0x7E,0x18,0x18,0x3C,0x00,0x00,0x00,0x00}, /* 6 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x3C,
0x3C,0x18,0x00,0x00,0x00,0x00,0x00,0x00}, /* 7 */
{0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xE7,0xC3,
0xC3,0xE7,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF}, /* 8 */
{0x00,0x00,0x00,0x00,0x00,0x3C,0x66,0x42,
0x42,0x66,0x3C,0x00,0x00,0x00,0x00,0x00}, /* 9 */
{0xFF,0xFF,0xFF,0xFF,0xFF,0xC3,0x99,0xBD,
0xBD,0x99,0xC3,0xFF,0xFF,0xFF,0xFF,0xFF}, /* 10 */
{0x00,0x00,0x1E,0x0E,0x1A,0x32,0x78,0xCC,
0xCC,0xCC,0xCC,0x78,0x00,0x00,0x00,0x00}, /* 11 */
{0x00,0x00,0x3C,0x66,0x66,0x66,0x66,0x3C,
0x18,0x7E,0x18,0x18,0x00,0x00,0x00,0x00}, /* 12 */
{0x00,0x00,0x3F,0x33,0x3F,0x30,0x30,0x30,
0x30,0x70,0xF0,0xE0,0x00,0x00,0x00,0x00}, /* 13 */
{0x00,0x00,0x7F,0x63,0x7F,0x63,0x63,0x63,
0x63,0x67,0xE7,0xE6,0xC0,0x00,0x00,0x00}, /* 14 */
{0x00,0x00,0x00,0x18,0x18,0xDB,0x3C,0xE7,
0x3C,0xDB,0x18,0x18,0x00,0x00,0x00,0x00}, /* 15 */
{0x00,0x80,0xC0,0xE0,0xF0,0xF8,0xFE,0xF8,
0xF0,0xE0,0xC0,0x80,0x00,0x00,0x00,0x00}, /* 16 */
{0x00,0x02,0x06,0x0E,0x1E,0x3E,0xFE,0x3E,
0x1E,0x0E,0x06,0x02,0x00,0x00,0x00,0x00}, /* 17 */
{0x00,0x00,0x18,0x3C,0x7E,0x18,0x18,0x18,
0x18,0x7E,0x3C,0x18,0x00,0x00,0x00,0x00}, /* 18 */
{0x00,0x00,0x66,0x66,0x66,0x66,0x66,0x66,
0x66,0x00,0x66,0x66,0x00,0x00,0x00,0x00}, /* 19 */
{0x00,0x00,0x7F,0xDB,0xDB,0xDB,0x7B,0x1B,
0x1B,0x1B,0x1B,0x1B,0x00,0x00,0x00,0x00}, /* 20 */
{0x00,0x7C,0xC6,0x60,0x38,0x6C,0xC6,0xC6,
0x6C,0x38,0x0C,0xC6,0x7C,0x00,0x00,0x00}, /* 21 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xFE,0xFE,0xFE,0xFE,0x00,0x00,0x00,0x00}, /* 22 */
{0x00,0x00,0x18,0x3C,0x7E,0x18,0x18,0x18,
0x18,0x7E,0x3C,0x18,0x7E,0x00,0x00,0x00}, /* 23 */
{0x00,0x00,0x18,0x3C,0x7E,0x18,0x18,0x18,
0x18,0x18,0x18,0x18,0x00,0x00,0x00,0x00}, /* 24 */
{0x00,0x00,0x18,0x18,0x18,0x18,0x18,0x18,
0x18,0x7E,0x3C,0x18,0x00,0x00,0x00,0x00}, /* 25 */
{0x00,0x00,0x00,0x00,0x00,0x18,0x0C,0xFE,
0x0C,0x18,0x00,0x00,0x00,0x00,0x00,0x00}, /* 26 */
{0x00,0x00,0x00,0x00,0x00,0x30,0x60,0xFE,
0x60,0x30,0x00,0x00,0x00,0x00,0x00,0x00}, /* 27 */
{0x00,0x00,0x00,0x00,0x00,0xC0,0xC0,0xC0,
0xC0,0xFE,0x00,0x00,0x00,0x00,0x00,0x00}, /* 28 */
{0x00,0x00,0x00,0x00,0x00,0x28,0x6C,0xFE,
0x6C,0x28,0x00,0x00,0x00,0x00,0x00,0x00}, /* 29 */
{0x00,0x00,0x00,0x00,0x10,0x38,0x38,0x7C,
0x7C,0xFE,0xFE,0x00,0x00,0x00,0x00,0x00}, /* 30 */
{0x00,0x00,0x00,0x00,0xFE,0xFE,0x7C,0x7C,
0x38,0x38,0x10,0x00,0x00,0x00,0x00,0x00}, /* 31 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 32 */
{0x00,0x00,0x18,0x3C,0x3C,0x3C,0x18,0x18,
0x18,0x00,0x18,0x18,0x00,0x00,0x00,0x00}, /* 33 */
{0x00,0x66,0x66,0x66,0x24,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 34 */
{0x00,0x00,0x00,0x6C,0x6C,0xFE,0x6C,0x6C,
0x6C,0xFE,0x6C,0x6C,0x00,0x00,0x00,0x00}, /* 35 */
{0x18,0x18,0x7C,0xC6,0xC2,0xC0,0x7C,0x06,
0x86,0xC6,0x7C,0x18,0x18,0x00,0x00,0x00}, /* 36 */
{0x00,0x00,0x00,0x00,0xC2,0xC6,0x0C,0x18,
0x30,0x60,0xC6,0x86,0x00,0x00,0x00,0x00}, /* 37 */
{0x00,0x00,0x38,0x6C,0x6C,0x38,0x76,0xDC,
0xCC,0xCC,0xCC,0x76,0x00,0x00,0x00,0x00}, /* 38 */
{0x00,0x30,0x30,0x30,0x60,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 39 */
{0x00,0x00,0x0C,0x18,0x30,0x30,0x30,0x30,
0x30,0x30,0x18,0x0C,0x00,0x00,0x00,0x00}, /* 40 */
{0x00,0x00,0x30,0x18,0x0C,0x0C,0x0C,0x0C,
0x0C,0x0C,0x18,0x30,0x00,0x00,0x00,0x00}, /* 41 */
{0x00,0x00,0x00,0x00,0x00,0x66,0x3C,0xFF,
0x3C,0x66,0x00,0x00,0x00,0x00,0x00,0x00}, /* 42 */
{0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x7E,
0x18,0x18,0x00,0x00,0x00,0x00,0x00,0x00}, /* 43 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x18,0x18,0x18,0x30,0x00,0x00,0x00}, /* 44 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFE,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 45 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00}, /* 46 */
{0x00,0x00,0x00,0x00,0x02,0x06,0x0C,0x18,
0x30,0x60,0xC0,0x80,0x00,0x00,0x00,0x00}, /* 47 */
{0x00,0x00,0x3C,0x66,0xC3,0xC3,0xDB,0xDB,
0xC3,0xC3,0x66,0x3C,0x00,0x00,0x00,0x00}, /* 48 */
{0x00,0x00,0x18,0x38,0x78,0x18,0x18,0x18,
0x18,0x18,0x18,0x7E,0x00,0x00,0x00,0x00}, /* 49 */
{0x00,0x00,0x7C,0xC6,0x06,0x0C,0x18,0x30,
0x60,0xC0,0xC6,0xFE,0x00,0x00,0x00,0x00}, /* 50 */
{0x00,0x00,0x7C,0xC6,0x06,0x06,0x3C,0x06,
0x06,0x06,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 51 */
{0x00,0x00,0x0C,0x1C,0x3C,0x6C,0xCC,0xFE,
0x0C,0x0C,0x0C,0x1E,0x00,0x00,0x00,0x00}, /* 52 */
{0x00,0x00,0xFE,0xC0,0xC0,0xC0,0xFC,0x06,
0x06,0x06,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 53 */
{0x00,0x00,0x38,0x60,0xC0,0xC0,0xFC,0xC6,
0xC6,0xC6,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 54 */
{0x00,0x00,0xFE,0xC6,0x06,0x06,0x0C,0x18,
0x30,0x30,0x30,0x30,0x00,0x00,0x00,0x00}, /* 55 */
{0x00,0x00,0x7C,0xC6,0xC6,0xC6,0x7C,0xC6,
0xC6,0xC6,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 56 */
{0x00,0x00,0x7C,0xC6,0xC6,0xC6,0x7E,0x06,
0x06,0x06,0x0C,0x78,0x00,0x00,0x00,0x00}, /* 57 */
{0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,
0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00}, /* 58 */
{0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,
0x00,0x18,0x18,0x30,0x00,0x00,0x00,0x00}, /* 59 */
{0x00,0x00,0x00,0x06,0x0C,0x18,0x30,0x60,
0x30,0x18,0x0C,0x06,0x00,0x00,0x00,0x00}, /* 60 */
{0x00,0x00,0x00,0x00,0x00,0x00,0xFE,0x00,
0x00,0xFE,0x00,0x00,0x00,0x00,0x00,0x00}, /* 61 */
{0x00,0x00,0x00,0x60,0x30,0x18,0x0C,0x06,
0x0C,0x18,0x30,0x60,0x00,0x00,0x00,0x00}, /* 62 */
{0x00,0x00,0x7C,0xC6,0xC6,0x0C,0x18,0x18,
0x18,0x00,0x18,0x18,0x00,0x00,0x00,0x00}, /* 63 */
{0x00,0x00,0x00,0x7C,0xC6,0xC6,0xDE,0xDE,
0xDE,0xDC,0xC0,0x7C,0x00,0x00,0x00,0x00}, /* 64 */
{0x00,0x00,0x10,0x38,0x6C,0xC6,0xC6,0xFE,
0xC6,0xC6,0xC6,0xC6,0x00,0x00,0x00,0x00}, /* 65 */
{0x00,0x00,0xFC,0x66,0x66,0x66,0x7C,0x66,
0x66,0x66,0x66,0xFC,0x00,0x00,0x00,0x00}, /* 66 */
{0x00,0x00,0x3C,0x66,0xC2,0xC0,0xC0,0xC0,
0xC0,0xC2,0x66,0x3C,0x00,0x00,0x00,0x00}, /* 67 */
{0x00,0x00,0xF8,0x6C,0x66,0x66,0x66,0x66,
0x66,0x66,0x6C,0xF8,0x00,0x00,0x00,0x00}, /* 68 */
{0x00,0x00,0xFE,0x66,0x62,0x68,0x78,0x68,
0x60,0x62,0x66,0xFE,0x00,0x00,0x00,0x00}, /* 69 */
{0x00,0x00,0xFE,0x66,0x62,0x68,0x78,0x68,
0x60,0x60,0x60,0xF0,0x00,0x00,0x00,0x00}, /* 70 */
{0x00,0x00,0x3C,0x66,0xC2,0xC0,0xC0,0xDE,
0xC6,0xC6,0x66,0x3A,0x00,0x00,0x00,0x00}, /* 71 */
{0x00,0x00,0xC6,0xC6,0xC6,0xC6,0xFE,0xC6,
0xC6,0xC6,0xC6,0xC6,0x00,0x00,0x00,0x00}, /* 72 */
{0x00,0x00,0x3C,0x18,0x18,0x18,0x18,0x18,
0x18,0x18,0x18,0x3C,0x00,0x00,0x00,0x00}, /* 73 */
{0x00,0x00,0x1E,0x0C,0x0C,0x0C,0x0C,0x0C,
0xCC,0xCC,0xCC,0x78,0x00,0x00,0x00,0x00}, /* 74 */
{0x00,0x00,0xE6,0x66,0x6C,0x6C,0x78,0x78,
0x6C,0x66,0x66,0xE6,0x00,0x00,0x00,0x00}, /* 75 */
{0x00,0x00,0xF0,0x60,0x60,0x60,0x60,0x60,
0x60,0x62,0x66,0xFE,0x00,0x00,0x00,0x00}, /* 76 */
{0x00,0x00,0xC6,0xEE,0xFE,0xFE,0xD6,0xC6,
0xC6,0xC6,0xC6,0xC6,0x00,0x00,0x00,0x00}, /* 77 */
{0x00,0x00,0xC6,0xE6,0xF6,0xFE,0xDE,0xCE,
0xC6,0xC6,0xC6,0xC6,0x00,0x00,0x00,0x00}, /* 78 */
{0x00,0x00,0x7C,0xC6,0xC6,0xC6,0xC6,0xC6,
0xC6,0xC6,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 79 */
{0x00,0x00,0xFC,0x66,0x66,0x66,0x7C,0x60,
0x60,0x60,0x60,0xF0,0x00,0x00,0x00,0x00}, /* 80 */
{0x00,0x00,0x7C,0xC6,0xC6,0xC6,0xC6,0xC6,
0xC6,0xD6,0xDE,0x7C,0x0C,0x0E,0x00,0x00}, /* 81 */
{0x00,0x00,0xFC,0x66,0x66,0x66,0x7C,0x6C,
0x66,0x66,0x66,0xE6,0x00,0x00,0x00,0x00}, /* 82 */
{0x00,0x00,0x7C,0xC6,0xC6,0x60,0x38,0x0C,
0x06,0xC6,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 83 */
{0x00,0x00,0x7E,0x7E,0x5A,0x18,0x18,0x18,
0x18,0x18,0x18,0x3C,0x00,0x00,0x00,0x00}, /* 84 */
{0x00,0x00,0xC6,0xC6,0xC6,0xC6,0xC6,0xC6,
0xC6,0xC6,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 85 */
{0x00,0x00,0xC6,0xC6,0xC6,0xC6,0xC6,0xC6,
0xC6,0x6C,0x38,0x10,0x00,0x00,0x00,0x00}, /* 86 */
{0x00,0x00,0xC6,0xC6,0xC6,0xC6,0xC6,0xD6,
0xD6,0xFE,0x6C,0x6C,0x00,0x00,0x00,0x00}, /* 87 */
{0x00,0x00,0xC6,0xC6,0x6C,0x6C,0x38,0x38,
0x6C,0x6C,0xC6,0xC6,0x00,0x00,0x00,0x00}, /* 88 */
{0x00,0x00,0x66,0x66,0x66,0x66,0x3C,0x18,
0x18,0x18,0x18,0x3C,0x00,0x00,0x00,0x00}, /* 89 */
{0x00,0x00,0xFE,0xC6,0x86,0x0C,0x18,0x30,
0x60,0xC2,0xC6,0xFE,0x00,0x00,0x00,0x00}, /* 90 */
{0x00,0x00,0x3C,0x30,0x30,0x30,0x30,0x30,
0x30,0x30,0x30,0x3C,0x00,0x00,0x00,0x00}, /* 91 */
{0x00,0x00,0x00,0x80,0xC0,0xE0,0x70,0x38,
0x1C,0x0E,0x06,0x02,0x00,0x00,0x00,0x00}, /* 92 */
{0x00,0x00,0x3C,0x0C,0x0C,0x0C,0x0C,0x0C,
0x0C,0x0C,0x0C,0x3C,0x00,0x00,0x00,0x00}, /* 93 */
{0x10,0x38,0x6C,0xC6,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 94 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00}, /* 95 */
{0x30,0x30,0x18,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 96 */
{0x00,0x00,0x00,0x00,0x00,0x78,0x0C,0x7C,
0xCC,0xCC,0xCC,0x76,0x00,0x00,0x00,0x00}, /* 97 */
{0x00,0x00,0xE0,0x60,0x60,0x78,0x6C,0x66,
0x66,0x66,0x66,0xDC,0x00,0x00,0x00,0x00}, /* 98 */
{0x00,0x00,0x00,0x00,0x00,0x7C,0xC6,0xC0,
0xC0,0xC0,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 99 */
{0x00,0x00,0x1C,0x0C,0x0C,0x3C,0x6C,0xCC,
0xCC,0xCC,0xCC,0x76,0x00,0x00,0x00,0x00}, /* 100 */
{0x00,0x00,0x00,0x00,0x00,0x7C,0xC6,0xFE,
0xC0,0xC0,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 101 */
{0x00,0x00,0x38,0x6C,0x64,0x60,0xF0,0x60,
0x60,0x60,0x60,0xF0,0x00,0x00,0x00,0x00}, /* 102 */
{0x00,0x00,0x00,0x00,0x00,0x76,0xCC,0xCC,
0xCC,0xCC,0xCC,0x7C,0x0C,0xCC,0x78,0x00}, /* 103 */
{0x00,0x00,0xE0,0x60,0x60,0x6C,0x76,0x66,
0x66,0x66,0x66,0xE6,0x00,0x00,0x00,0x00}, /* 104 */
{0x00,0x00,0x18,0x18,0x00,0x38,0x18,0x18,
0x18,0x18,0x18,0x3C,0x00,0x00,0x00,0x00}, /* 105 */
{0x00,0x00,0x06,0x06,0x00,0x0E,0x06,0x06,
0x06,0x06,0x06,0x06,0x66,0x66,0x3C,0x00}, /* 106 */
{0x00,0x00,0xE0,0x60,0x60,0x66,0x6C,0x78,
0x78,0x6C,0x66,0xE6,0x00,0x00,0x00,0x00}, /* 107 */
{0x00,0x00,0x38,0x18,0x18,0x18,0x18,0x18,
0x18,0x18,0x18,0x3C,0x00,0x00,0x00,0x00}, /* 108 */
{0x00,0x00,0x00,0x00,0x00,0xEC,0xFE,0xD6,
0xD6,0xD6,0xD6,0xD6,0x00,0x00,0x00,0x00}, /* 109 */
{0x00,0x00,0x00,0x00,0x00,0xDC,0x66,0x66,
0x66,0x66,0x66,0x66,0x00,0x00,0x00,0x00}, /* 110 */
{0x00,0x00,0x00,0x00,0x00,0x7C,0xC6,0xC6,
0xC6,0xC6,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 111 */
{0x00,0x00,0x00,0x00,0x00,0xDC,0x66,0x66,
0x66,0x66,0x66,0x7C,0x60,0x60,0xF0,0x00}, /* 112 */
{0x00,0x00,0x00,0x00,0x00,0x76,0xCC,0xCC,
0xCC,0xCC,0xCC,0x7C,0x0C,0x0C,0x1E,0x00}, /* 113 */
{0x00,0x00,0x00,0x00,0x00,0xDC,0x76,0x62,
0x60,0x60,0x60,0xF0,0x00,0x00,0x00,0x00}, /* 114 */
{0x00,0x00,0x00,0x00,0x00,0x7C,0xC6,0x60,
0x38,0x0C,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 115 */
{0x00,0x00,0x10,0x30,0x30,0xFC,0x30,0x30,
0x30,0x30,0x36,0x1C,0x00,0x00,0x00,0x00}, /* 116 */
{0x00,0x00,0x00,0x00,0x00,0xCC,0xCC,0xCC,
0xCC,0xCC,0xCC,0x76,0x00,0x00,0x00,0x00}, /* 117 */
{0x00,0x00,0x00,0x00,0x00,0x66,0x66,0x66,
0x66,0x66,0x3C,0x18,0x00,0x00,0x00,0x00}, /* 118 */
{0x00,0x00,0x00,0x00,0x00,0xC6,0xC6,0xC6,
0xD6,0xD6,0xFE,0x6C,0x00,0x00,0x00,0x00}, /* 119 */
{0x00,0x00,0x00,0x00,0x00,0xC6,0x6C,0x38,
0x38,0x38,0x6C,0xC6,0x00,0x00,0x00,0x00}, /* 120 */
{0x00,0x00,0x00,0x00,0x00,0xC6,0xC6,0xC6,
0xC6,0xC6,0xC6,0x7E,0x06,0x0C,0xF8,0x00}, /* 121 */
{0x00,0x00,0x00,0x00,0x00,0xFE,0xCC,0x18,
0x30,0x60,0xC6,0xFE,0x00,0x00,0x00,0x00}, /* 122 */
{0x00,0x00,0x0E,0x18,0x18,0x18,0x70,0x18,
0x18,0x18,0x18,0x0E,0x00,0x00,0x00,0x00}, /* 123 */
{0x00,0x00,0x18,0x18,0x18,0x18,0x00,0x18,
0x18,0x18,0x18,0x18,0x00,0x00,0x00,0x00}, /* 124 */
{0x00,0x00,0x70,0x18,0x18,0x18,0x0E,0x18,
0x18,0x18,0x18,0x70,0x00,0x00,0x00,0x00}, /* 125 */
{0x00,0x00,0x76,0xDC,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 126 */
{0x00,0x00,0x00,0x00,0x10,0x38,0x6C,0xC6,
0xC6,0xC6,0xFE,0x00,0x00,0x00,0x00,0x00}, /* 127 */
{0x00,0x00,0x3C,0x66,0xC2,0xC0,0xC0,0xC0,
0xC2,0x66,0x3C,0x0C,0x06,0x7C,0x00,0x00}, /* 128 */
{0x00,0x00,0xCC,0x00,0x00,0xCC,0xCC,0xCC,
0xCC,0xCC,0xCC,0x76,0x00,0x00,0x00,0x00}, /* 129 */
{0x00,0x0C,0x18,0x30,0x00,0x7C,0xC6,0xFE,
0xC0,0xC0,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 130 */
{0x00,0x10,0x38,0x6C,0x00,0x78,0x0C,0x7C,
0xCC,0xCC,0xCC,0x76,0x00,0x00,0x00,0x00}, /* 131 */
{0x00,0x00,0xCC,0x00,0x00,0x78,0x0C,0x7C,
0xCC,0xCC,0xCC,0x76,0x00,0x00,0x00,0x00}, /* 132 */
{0x00,0x60,0x30,0x18,0x00,0x78,0x0C,0x7C,
0xCC,0xCC,0xCC,0x76,0x00,0x00,0x00,0x00}, /* 133 */
{0x00,0x38,0x6C,0x38,0x00,0x78,0x0C,0x7C,
0xCC,0xCC,0xCC,0x76,0x00,0x00,0x00,0x00}, /* 134 */
{0x00,0x00,0x00,0x00,0x3C,0x66,0x60,0x60,
0x66,0x3C,0x0C,0x06,0x3C,0x00,0x00,0x00}, /* 135 */
{0x00,0x10,0x38,0x6C,0x00,0x7C,0xC6,0xFE,
0xC0,0xC0,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 136 */
{0x00,0x00,0xC6,0x00,0x00,0x7C,0xC6,0xFE,
0xC0,0xC0,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 137 */
{0x00,0x60,0x30,0x18,0x00,0x7C,0xC6,0xFE,
0xC0,0xC0,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 138 */
{0x00,0x00,0x66,0x00,0x00,0x38,0x18,0x18,
0x18,0x18,0x18,0x3C,0x00,0x00,0x00,0x00}, /* 139 */
{0x00,0x18,0x3C,0x66,0x00,0x38,0x18,0x18,
0x18,0x18,0x18,0x3C,0x00,0x00,0x00,0x00}, /* 140 */
{0x00,0x60,0x30,0x18,0x00,0x38,0x18,0x18,
0x18,0x18,0x18,0x3C,0x00,0x00,0x00,0x00}, /* 141 */
{0x00,0xC6,0x00,0x10,0x38,0x6C,0xC6,0xC6,
0xFE,0xC6,0xC6,0xC6,0x00,0x00,0x00,0x00}, /* 142 */
{0x38,0x6C,0x38,0x00,0x38,0x6C,0xC6,0xC6,
0xFE,0xC6,0xC6,0xC6,0x00,0x00,0x00,0x00}, /* 143 */
{0x18,0x30,0x60,0x00,0xFE,0x66,0x60,0x7C,
0x60,0x60,0x66,0xFE,0x00,0x00,0x00,0x00}, /* 144 */
{0x00,0x00,0x00,0x00,0x00,0xCC,0x76,0x36,
0x7E,0xD8,0xD8,0x6E,0x00,0x00,0x00,0x00}, /* 145 */
{0x00,0x00,0x3E,0x6C,0xCC,0xCC,0xFE,0xCC,
0xCC,0xCC,0xCC,0xCE,0x00,0x00,0x00,0x00}, /* 146 */
{0x00,0x10,0x38,0x6C,0x00,0x7C,0xC6,0xC6,
0xC6,0xC6,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 147 */
{0x00,0x00,0xC6,0x00,0x00,0x7C,0xC6,0xC6,
0xC6,0xC6,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 148 */
{0x00,0x60,0x30,0x18,0x00,0x7C,0xC6,0xC6,
0xC6,0xC6,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 149 */
{0x00,0x30,0x78,0xCC,0x00,0xCC,0xCC,0xCC,
0xCC,0xCC,0xCC,0x76,0x00,0x00,0x00,0x00}, /* 150 */
{0x00,0x60,0x30,0x18,0x00,0xCC,0xCC,0xCC,
0xCC,0xCC,0xCC,0x76,0x00,0x00,0x00,0x00}, /* 151 */
{0x00,0x00,0xC6,0x00,0x00,0xC6,0xC6,0xC6,
0xC6,0xC6,0xC6,0x7E,0x06,0x0C,0x78,0x00}, /* 152 */
{0x00,0xC6,0x00,0x7C,0xC6,0xC6,0xC6,0xC6,
0xC6,0xC6,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 153 */
{0x00,0xC6,0x00,0xC6,0xC6,0xC6,0xC6,0xC6,
0xC6,0xC6,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 154 */
{0x00,0x18,0x18,0x3C,0x66,0x60,0x60,0x60,
0x66,0x3C,0x18,0x18,0x00,0x00,0x00,0x00}, /* 155 */
{0x00,0x38,0x6C,0x64,0x60,0xF0,0x60,0x60,
0x60,0x60,0xE6,0xFC,0x00,0x00,0x00,0x00}, /* 156 */
{0x00,0x00,0x66,0x66,0x3C,0x18,0x7E,0x18,
0x7E,0x18,0x18,0x18,0x00,0x00,0x00,0x00}, /* 157 */
{0x00,0xF8,0xCC,0xCC,0xF8,0xC4,0xCC,0xDE,
0xCC,0xCC,0xCC,0xC6,0x00,0x00,0x00,0x00}, /* 158 */
{0x00,0x0E,0x1B,0x18,0x18,0x18,0x7E,0x18,
0x18,0x18,0x18,0x18,0xD8,0x70,0x00,0x00}, /* 159 */
{0x00,0x18,0x30,0x60,0x00,0x78,0x0C,0x7C,
0xCC,0xCC,0xCC,0x76,0x00,0x00,0x00,0x00}, /* 160 */
{0x00,0x0C,0x18,0x30,0x00,0x38,0x18,0x18,
0x18,0x18,0x18,0x3C,0x00,0x00,0x00,0x00}, /* 161 */
{0x00,0x18,0x30,0x60,0x00,0x7C,0xC6,0xC6,
0xC6,0xC6,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 162 */
{0x00,0x18,0x30,0x60,0x00,0xCC,0xCC,0xCC,
0xCC,0xCC,0xCC,0x76,0x00,0x00,0x00,0x00}, /* 163 */
{0x00,0x00,0x76,0xDC,0x00,0xDC,0x66,0x66,
0x66,0x66,0x66,0x66,0x00,0x00,0x00,0x00}, /* 164 */
{0x76,0xDC,0x00,0xC6,0xE6,0xF6,0xFE,0xDE,
0xCE,0xC6,0xC6,0xC6,0x00,0x00,0x00,0x00}, /* 165 */
{0x00,0x3C,0x6C,0x6C,0x3E,0x00,0x7E,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 166 */
{0x00,0x38,0x6C,0x6C,0x38,0x00,0x7C,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 167 */
{0x00,0x00,0x30,0x30,0x00,0x30,0x30,0x60,
0xC0,0xC6,0xC6,0x7C,0x00,0x00,0x00,0x00}, /* 168 */
{0x00,0x00,0x00,0x00,0x00,0x00,0xFE,0xC0,
0xC0,0xC0,0xC0,0x00,0x00,0x00,0x00,0x00}, /* 169 */
{0x00,0x00,0x00,0x00,0x00,0x00,0xFE,0x06,
0x06,0x06,0x06,0x00,0x00,0x00,0x00,0x00}, /* 170 */
{0x00,0xC0,0xC0,0xC2,0xC6,0xCC,0x18,0x30,
0x60,0xCE,0x93,0x06,0x0C,0x1F,0x00,0x00}, /* 171 */
{0x00,0xC0,0xC0,0xC2,0xC6,0xCC,0x18,0x30,
0x66,0xCE,0x9A,0x3F,0x06,0x0F,0x00,0x00}, /* 172 */
{0x00,0x00,0x18,0x18,0x00,0x18,0x18,0x18,
0x3C,0x3C,0x3C,0x18,0x00,0x00,0x00,0x00}, /* 173 */
{0x00,0x00,0x00,0x00,0x00,0x33,0x66,0xCC,
0x66,0x33,0x00,0x00,0x00,0x00,0x00,0x00}, /* 174 */
{0x00,0x00,0x00,0x00,0x00,0xCC,0x66,0x33,
0x66,0xCC,0x00,0x00,0x00,0x00,0x00,0x00}, /* 175 */
{0x11,0x44,0x11,0x44,0x11,0x44,0x11,0x44,
0x11,0x44,0x11,0x44,0x11,0x44,0x11,0x44}, /* 176 */
{0x55,0xAA,0x55,0xAA,0x55,0xAA,0x55,0xAA,
0x55,0xAA,0x55,0xAA,0x55,0xAA,0x55,0xAA}, /* 177 */
{0xDD,0x77,0xDD,0x77,0xDD,0x77,0xDD,0x77,
0xDD,0x77,0xDD,0x77,0xDD,0x77,0xDD,0x77}, /* 178 */
{0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18}, /* 179 */
{0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xF8,
0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18}, /* 180 */
{0x18,0x18,0x18,0x18,0x18,0xF8,0x18,0xF8,
0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18}, /* 181 */
{0x36,0x36,0x36,0x36,0x36,0x36,0x36,0xF6,
0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36}, /* 182 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFE,
0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36}, /* 183 */
{0x00,0x00,0x00,0x00,0x00,0xF8,0x18,0xF8,
0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18}, /* 184 */
{0x36,0x36,0x36,0x36,0x36,0xF6,0x06,0xF6,
0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36}, /* 185 */
{0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36,
0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36}, /* 186 */
{0x00,0x00,0x00,0x00,0x00,0xFE,0x06,0xF6,
0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36}, /* 187 */
{0x36,0x36,0x36,0x36,0x36,0xF6,0x06,0xFE,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 188 */
{0x36,0x36,0x36,0x36,0x36,0x36,0x36,0xFE,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 189 */
{0x18,0x18,0x18,0x18,0x18,0xF8,0x18,0xF8,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 190 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF8,
0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18}, /* 191 */
{0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x1F,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 192 */
{0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xFF,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 193 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,
0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18}, /* 194 */
{0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x1F,
0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18}, /* 195 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 196 */
{0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xFF,
0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18}, /* 197 */
{0x18,0x18,0x18,0x18,0x18,0x1F,0x18,0x1F,
0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18}, /* 198 */
{0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x37,
0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36}, /* 199 */
{0x36,0x36,0x36,0x36,0x36,0x37,0x30,0x3F,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 200 */
{0x00,0x00,0x00,0x00,0x00,0x3F,0x30,0x37,
0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36}, /* 201 */
{0x36,0x36,0x36,0x36,0x36,0xF7,0x00,0xFF,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 202 */
{0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0xF7,
0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36}, /* 203 */
{0x36,0x36,0x36,0x36,0x36,0x37,0x30,0x37,
0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36}, /* 204 */
{0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0xFF,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 205 */
{0x36,0x36,0x36,0x36,0x36,0xF7,0x00,0xF7,
0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36}, /* 206 */
{0x18,0x18,0x18,0x18,0x18,0xFF,0x00,0xFF,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 207 */
{0x36,0x36,0x36,0x36,0x36,0x36,0x36,0xFF,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 208 */
{0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0xFF,
0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18}, /* 209 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,
0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36}, /* 210 */
{0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x3F,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 211 */
{0x18,0x18,0x18,0x18,0x18,0x1F,0x18,0x1F,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 212 */
{0x00,0x00,0x00,0x00,0x00,0x1F,0x18,0x1F,
0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18}, /* 213 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,
0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36}, /* 214 */
{0x36,0x36,0x36,0x36,0x36,0x36,0x36,0xFF,
0x36,0x36,0x36,0x36,0x36,0x36,0x36,0x36}, /* 215 */
{0x18,0x18,0x18,0x18,0x18,0xFF,0x18,0xFF,
0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18}, /* 216 */
{0x18,0x18,0x18,0x18,0x18,0x18,0x18,0xF8,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 217 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1F,
0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18}, /* 218 */
{0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF}, /* 219 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF}, /* 220 */
{0xF0,0xF0,0xF0,0xF0,0xF0,0xF0,0xF0,0xF0,
0xF0,0xF0,0xF0,0xF0,0xF0,0xF0,0xF0,0xF0}, /* 221 */
{0x0F,0x0F,0x0F,0x0F,0x0F,0x0F,0x0F,0x0F,
0x0F,0x0F,0x0F,0x0F,0x0F,0x0F,0x0F,0x0F}, /* 222 */
{0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 223 */
{0x00,0x00,0x00,0x00,0x00,0x76,0xDC,0xD8,
0xD8,0xD8,0xDC,0x76,0x00,0x00,0x00,0x00}, /* 224 */
{0x00,0x00,0x78,0xCC,0xCC,0xCC,0xD8,0xCC,
0xC6,0xC6,0xC6,0xCC,0x00,0x00,0x00,0x00}, /* 225 */
{0x00,0x00,0xFE,0xC6,0xC6,0xC0,0xC0,0xC0,
0xC0,0xC0,0xC0,0xC0,0x00,0x00,0x00,0x00}, /* 226 */
{0x00,0x00,0x00,0x00,0xFE,0x6C,0x6C,0x6C,
0x6C,0x6C,0x6C,0x6C,0x00,0x00,0x00,0x00}, /* 227 */
{0x00,0x00,0x00,0xFE,0xC6,0x60,0x30,0x18,
0x30,0x60,0xC6,0xFE,0x00,0x00,0x00,0x00}, /* 228 */
{0x00,0x00,0x00,0x00,0x00,0x7E,0xD8,0xD8,
0xD8,0xD8,0xD8,0x70,0x00,0x00,0x00,0x00}, /* 229 */
{0x00,0x00,0x00,0x00,0x66,0x66,0x66,0x66,
0x66,0x7C,0x60,0x60,0xC0,0x00,0x00,0x00}, /* 230 */
{0x00,0x00,0x00,0x00,0x76,0xDC,0x18,0x18,
0x18,0x18,0x18,0x18,0x00,0x00,0x00,0x00}, /* 231 */
{0x00,0x00,0x00,0x7E,0x18,0x3C,0x66,0x66,
0x66,0x3C,0x18,0x7E,0x00,0x00,0x00,0x00}, /* 232 */
{0x00,0x00,0x00,0x38,0x6C,0xC6,0xC6,0xFE,
0xC6,0xC6,0x6C,0x38,0x00,0x00,0x00,0x00}, /* 233 */
{0x00,0x00,0x38,0x6C,0xC6,0xC6,0xC6,0x6C,
0x6C,0x6C,0x6C,0xEE,0x00,0x00,0x00,0x00}, /* 234 */
{0x00,0x00,0x1E,0x30,0x18,0x0C,0x3E,0x66,
0x66,0x66,0x66,0x3C,0x00,0x00,0x00,0x00}, /* 235 */
{0x00,0x00,0x00,0x00,0x00,0x7E,0xDB,0xDB,
0xDB,0x7E,0x00,0x00,0x00,0x00,0x00,0x00}, /* 236 */
{0x00,0x00,0x00,0x03,0x06,0x7E,0xCF,0xDB,
0xF3,0x7E,0x60,0xC0,0x00,0x00,0x00,0x00}, /* 237 */
{0x00,0x00,0x1C,0x30,0x60,0x60,0x7C,0x60,
0x60,0x60,0x30,0x1C,0x00,0x00,0x00,0x00}, /* 238 */
{0x00,0x00,0x00,0x7C,0xC6,0xC6,0xC6,0xC6,
0xC6,0xC6,0xC6,0xC6,0x00,0x00,0x00,0x00}, /* 239 */
{0x00,0x00,0x00,0x00,0xFE,0x00,0x00,0xFE,
0x00,0x00,0xFE,0x00,0x00,0x00,0x00,0x00}, /* 240 */
{0x00,0x00,0x00,0x00,0x18,0x18,0x7E,0x18,
0x18,0x00,0x00,0xFF,0x00,0x00,0x00,0x00}, /* 241 */
{0x00,0x00,0x00,0x30,0x18,0x0C,0x06,0x0C,
0x18,0x30,0x00,0x7E,0x00,0x00,0x00,0x00}, /* 242 */
{0x00,0x00,0x00,0x0C,0x18,0x30,0x60,0x30,
0x18,0x0C,0x00,0x7E,0x00,0x00,0x00,0x00}, /* 243 */
{0x00,0x00,0x0E,0x1B,0x1B,0x18,0x18,0x18,
0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18}, /* 244 */
{0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,
0xD8,0xD8,0xD8,0x70,0x00,0x00,0x00,0x00}, /* 245 */
{0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x7E,
0x00,0x18,0x18,0x00,0x00,0x00,0x00,0x00}, /* 246 */
{0x00,0x00,0x00,0x00,0x00,0x76,0xDC,0x00,
0x76,0xDC,0x00,0x00,0x00,0x00,0x00,0x00}, /* 247 */
{0x00,0x38,0x6C,0x6C,0x38,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 248 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,
0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 249 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 250 */
{0x00,0x0F,0x0C,0x0C,0x0C,0x0C,0x0C,0xEC,
0x6C,0x6C,0x3C,0x1C,0x00,0x00,0x00,0x00}, /* 251 */
{0x00,0xD8,0x6C,0x6C,0x6C,0x6C,0x6C,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 252 */
{0x00,0x70,0x98,0x30,0x60,0xC8,0xF8,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, /* 253 */
{0x00,0x00,0x00,0x00,0x7C,0x7C,0x7C,0x7C,
0x7C,0x7C,0x7C,0x00,0x00,0x00,0x00,0x00}, /* 254 */
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}}; /* 255 */

